<?php
/**
 * Twenty Twenty-Four functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Twenty Twenty-Four
 * @since Twenty Twenty-Four 1.0
 */

/**
 * Register block styles.
 */

if ( ! function_exists( 'twentytwentyfour_block_styles' ) ) :
	/**
	 * Register custom block styles
	 *
	 * @since Twenty Twenty-Four 1.0
	 * @return void
	 */
	function twentytwentyfour_block_styles() {

		register_block_style(
			'core/details',
			array(
				'name'         => 'arrow-icon-details',
				'label'        => __( 'Arrow icon', 'twentytwentyfour' ),
				/*
				 * Styles for the custom Arrow icon style of the Details block
				 */
				'inline_style' => '
				.is-style-arrow-icon-details {
					padding-top: var(--wp--preset--spacing--10);
					padding-bottom: var(--wp--preset--spacing--10);
				}

				.is-style-arrow-icon-details summary {
					list-style-type: "\2193\00a0\00a0\00a0";
				}

				.is-style-arrow-icon-details[open]>summary {
					list-style-type: "\2192\00a0\00a0\00a0";
				}',
			)
		);
		register_block_style(
			'core/post-terms',
			array(
				'name'         => 'pill',
				'label'        => __( 'Pill', 'twentytwentyfour' ),
				/*
				 * Styles variation for post terms
				 * https://github.com/WordPress/gutenberg/issues/24956
				 */
				'inline_style' => '
				.is-style-pill a,
				.is-style-pill span:not([class], [data-rich-text-placeholder]) {
					display: inline-block;
					background-color: var(--wp--preset--color--base-2);
					padding: 0.375rem 0.875rem;
					border-radius: var(--wp--preset--spacing--20);
				}

				.is-style-pill a:hover {
					background-color: var(--wp--preset--color--contrast-3);
				}',
			)
		);
		register_block_style(
			'core/list',
			array(
				'name'         => 'checkmark-list',
				'label'        => __( 'Checkmark', 'twentytwentyfour' ),
				/*
				 * Styles for the custom checkmark list block style
				 * https://github.com/WordPress/gutenberg/issues/51480
				 */
				'inline_style' => '
				ul.is-style-checkmark-list {
					list-style-type: "\2713";
				}

				ul.is-style-checkmark-list li {
					padding-inline-start: 1ch;
				}',
			)
		);
		register_block_style(
			'core/navigation-link',
			array(
				'name'         => 'arrow-link',
				'label'        => __( 'With arrow', 'twentytwentyfour' ),
				/*
				 * Styles for the custom arrow nav link block style
				 */
				'inline_style' => '
				.is-style-arrow-link .wp-block-navigation-item__label:after {
					content: "\2197";
					padding-inline-start: 0.25rem;
					vertical-align: middle;
					text-decoration: none;
					display: inline-block;
				}',
			)
		);
		register_block_style(
			'core/heading',
			array(
				'name'         => 'asterisk',
				'label'        => __( 'With asterisk', 'twentytwentyfour' ),
				'inline_style' => "
				.is-style-asterisk:before {
					content: '';
					width: 1.5rem;
					height: 3rem;
					background: var(--wp--preset--color--contrast-2, currentColor);
					clip-path: path('M11.93.684v8.039l5.633-5.633 1.216 1.23-5.66 5.66h8.04v1.737H13.2l5.701 5.701-1.23 1.23-5.742-5.742V21h-1.737v-8.094l-5.77 5.77-1.23-1.217 5.743-5.742H.842V9.98h8.162l-5.701-5.7 1.23-1.231 5.66 5.66V.684h1.737Z');
					display: block;
				}

				/* Hide the asterisk if the heading has no content, to avoid using empty headings to display the asterisk only, which is an A11Y issue */
				.is-style-asterisk:empty:before {
					content: none;
				}

				.is-style-asterisk:-moz-only-whitespace:before {
					content: none;
				}

				.is-style-asterisk.has-text-align-center:before {
					margin: 0 auto;
				}

				.is-style-asterisk.has-text-align-right:before {
					margin-left: auto;
				}

				.rtl .is-style-asterisk.has-text-align-left:before {
					margin-right: auto;
				}",
			)
		);
	}
endif;

add_action( 'init', 'twentytwentyfour_block_styles' );

/**
 * Enqueue block stylesheets.
 */

if ( ! function_exists( 'twentytwentyfour_block_stylesheets' ) ) :
	/**
	 * Enqueue custom block stylesheets
	 *
	 * @since Twenty Twenty-Four 1.0
	 * @return void
	 */
	function twentytwentyfour_block_stylesheets() {
		/**
		 * The wp_enqueue_block_style() function allows us to enqueue a stylesheet
		 * for a specific block. These will only get loaded when the block is rendered
		 * (both in the editor and on the front end), improving performance
		 * and reducing the amount of data requested by visitors.
		 *
		 * See https://make.wordpress.org/core/2021/12/15/using-multiple-stylesheets-per-block/ for more info.
		 */
		wp_enqueue_block_style(
			'core/button',
			array(
				'handle' => 'twentytwentyfour-button-style-outline',
				'src'    => get_parent_theme_file_uri( 'assets/css/button-outline.css' ),
				'ver'    => wp_get_theme( get_template() )->get( 'Version' ),
				'path'   => get_parent_theme_file_path( 'assets/css/button-outline.css' ),
			)
		);
	}
endif;

add_action( 'init', 'twentytwentyfour_block_stylesheets' );

/**
 * Register pattern categories.
 */

if ( ! function_exists( 'twentytwentyfour_pattern_categories' ) ) :
	/**
	 * Register pattern categories
	 *
	 * @since Twenty Twenty-Four 1.0
	 * @return void
	 */
	function twentytwentyfour_pattern_categories() {

		register_block_pattern_category(
			'twentytwentyfour_page',
			array(
				'label'       => _x( 'Pages', 'Block pattern category', 'twentytwentyfour' ),
				'description' => __( 'A collection of full page layouts.', 'twentytwentyfour' ),
			)
		);
	}
endif;

add_action( 'init', 'twentytwentyfour_pattern_categories' );

function enqueue_my_theme_styles() {
    // Enqueue main stylesheet
    //wp_enqueue_style( 'theme-style', get_stylesheet_uri() );

    // Enqueue additional stylesheets
    wp_enqueue_style( 'components-style', get_template_directory_uri() . '/components.css.css', array(), '1.0' );
    wp_enqueue_style( 'custom-style', get_template_directory_uri() . '/style.css', array(), '1.0' );
    wp_enqueue_style( 'theme-style-2', get_template_directory_uri() . '/theme.css.css', array(), '1.0' );
}
add_action( 'wp_enqueue_scripts', 'enqueue_my_theme_styles' );



// Add Shortcode
function our_logo() {
	$site_settings_page_id = 92;
	$site_logo = get_field ('site_logo',$site_settings_page_id );
    // Return HTML output
    $output = '<div style="text-align: center;"><img src="'.$site_logo.'" alt="Logo" width="161" height="50" />';
    
    return $output;
}
add_shortcode('logo', 'our_logo');

function our_security() {
    // Return HTML output
    $output = '<a id="dialog:forgotButton" href="#" style="line-height: 2em; font-weight: bold; font-size: 0.88em;">Forgot Password</a>
	<div style="margin: 1em 0 1em 0;">Security
			&nbsp;&nbsp;&nbsp;
			<a href="#" <span id="dialog:securityTip" style="font-style:italic; font-weight: lighter;">What is this?</span>
			</a><table id="dialog:privacyselector">
			<tbody><tr>
		<td>
		<input type="radio" checked="checked" name="dialog:privacyselector" id="dialog:privacyselector:0" value="false"><label for="dialog:privacyselector:0"> This is a public or shared computer</label></td>
			</tr>
			<tr>
		<td>
		<input type="radio" name="dialog:privacyselector" id="dialog:privacyselector:1" value="true"><label for="dialog:privacyselector:1"> This is a private computer</label></td>
			</tr>
		</tbody></table><div id="dialog:securityexplanation" class="ui-panel ui-widget ui-widget-content ui-corner-all" style="display:none;" data-widget="widget_dialog_securityexplanation"><div id="dialog:securityexplanation_content" class="ui-panel-content ui-widget-content">This
		web site can remember your credentials.  If you are using a public or 
		shared computer, you can choose that option to have it not remember your
		log in.</div></div></div>';
    
    return $output;
}
add_shortcode('security', 'our_security');

function our_email_page() {
	$email_page_id = 28;
	$email_subject = get_field ('email_subject',$email_page_id );
	$email_image = get_field ('email_image',$email_page_id );
	$email_from = get_field ('email_from',$email_page_id );
	$email_to = get_field ('email_to',$email_page_id );
	$email_cc = get_field ('email_cc',$email_page_id );
	$email_sent = get_field ('email_sent',$email_page_id );
	$email_attachment = get_field ('email_attachment',$email_page_id );

	$attachment_html = '';
	if($email_attachment) {
		// Get the file name
		$email_attachment_name = $email_attachment['filename'];	
		// Get the file URL
		$email_attachment_url = $email_attachment['url'];
		$attachment_html = '<div class="header-overflow-field header-attachment-field"><span class="header-attachment-item"><a target="_blank" href="'.$email_attachment_url.'" style="white-space:nowrap"><img src="'.site_url().'/wp-content/uploads/2024/05/pdf.gif" alt="" style="position:relative;top:0.47ex;padding-right:0.5em;border:0" title="">'.$email_attachment_name.'</a></span></div>';
	}
	$email_html = get_field ('email_html',$email_page_id );
    // Return HTML output
    $output = '<form id="readTB" name="readTB" method="post" action="'.site_url().'" enctype="application/x-www-form-urlencoded">
	<input type="hidden" name="readTB" value="readTB">
	<div class="header"><img src="'.$email_image.'" alt="Proofpoint" style="width: 150px;"><input id="readTB:logoutButton" type="submit" name="readTB:logoutButton" value="Logout" style="position: fixed; right: 13px; top: 5px" class="toolbarButton secondaryButton"></div><div id="readTB:menu" class="ui-menu ui-menubar ui-widget ui-widget-content ui-corner-all ui-helper-clearfix messageToolbar" role="menubar"><div tabindex="0" class="ui-helper-hidden-accessible" aria-label="Message Actions"></div><ul class="ui-menu-list ui-helper-reset"><li class="ui-menuitem ui-widget ui-corner-all" role="menuitem"><a tabindex="-1" id="readTB:replyButton" class="ui-menuitem-link ui-corner-all toolbarButton" href="#" onclick="resetTimeoutTimer();;PrimeFaces.ab({s:"readTB:replyButton",f:"readTB"});return false;"><span class="ui-menuitem-text">Reply</span></a></li><li class="ui-menuitem ui-widget ui-corner-all" role="menuitem"><a tabindex="-1" id="readTB:replyAllButton" class="ui-menuitem-link ui-corner-all toolbarButton" href="#" onclick="resetTimeoutTimer();;PrimeFaces.ab({s:"readTB:replyAllButton",f:"readTB"});return false;"><span class="ui-menuitem-text">Reply All</span></a></li><li class="ui-menuitem ui-widget ui-corner-all" role="menuitem"><a tabindex="-1" id="readTB:forwardButton" class="ui-menuitem-link ui-corner-all toolbarButton" href="#" onclick="resetTimeoutTimer();;PrimeFaces.ab({s:"readTB:forwardButton",f:"readTB"});return false;"><span class="ui-menuitem-text">Forward</span></a></li><li class="ui-menuitem ui-widget ui-corner-all" role="menuitem"><a tabindex="-1" id="readTB:helpButton" class="ui-menuitem-link ui-corner-all toolbarButton" href="https://ppencrypt2.ppsecureemail.com/securereader/help.jsf" target="_blank"><span class="ui-menuitem-text">Help</span></a></li></ul></div>
					<script>
						addAccessibilityAttributesToReadToolbar();
					</script><input type="hidden" name="javax.faces.ViewState" id="j_id1:javax.faces.ViewState:0" value="1114156564907687641:1000973990568176313" autocomplete="off">
	</form><div class="read-headers" style="padding-top:10px">
	<form id="readHdr" name="readHdr" method="post" action="/" enctype="application/x-www-form-urlencoded">
	<input type="hidden" name="readHdr" value="readHdr">
	<span id="readHdr:dsig" class="dsig-panel">Your connection is SECURE<img src="'.site_url().'/wp-content/uploads/2024/05/GreenCheck.png" alt="" style="position:relative;top:4px;margin-left:0.5em" title=""></span><table class="header-table" cellpadding="0" cellspacing="0" role="presentation">
	<thead role="presentation">
	<tr><th class="header-subject-field" colspan="2" scope="colgroup">'.$email_subject.'</th></tr>
	</thead>
	<tbody role="presentation">
	<tr role="presentation">
	<td class="header-field-label" role="presentation">From:</td>
	<td class=" header-field-value" role="presentation"><span>'.$email_from.'</span></td>
	</tr>
	<tr role="presentation">
	<td class="header-field-label" role="presentation">To:</td>
	<td class=" header-field-value" role="presentation"><span>'.$email_to.'</span></td>
	</tr>
	<tr role="presentation">
	<td class="header-field-label" role="presentation">Cc:</td>
	<td class=" header-field-value" role="presentation">
							<span>
							'.$email_cc.'
							</span></td>
	</tr>
	<tr role="presentation">
	<td class="header-field-label" role="presentation">Sent:</td>
	<td class=" header-field-value" role="presentation">
							<span>
							'.$email_sent.'
							</span></td>
	</tr>
	</tbody>
	</table>
	<table class="header-table" cellpadding="0" cellspacing="0">
	<tbody>
	<tr>
	<td class="header-field-label">Attachments:</td>
	<td class=" header-field-value">'.$attachment_html.'</td>
	</tr>
	</tbody>
	</table>
	<input type="hidden" name="javax.faces.ViewState" id="j_id1:javax.faces.ViewState:1" value="1114156564907687641:1000973990568176313" autocomplete="off">
	</form></div>
	<div class="read-container"><div id="messagepanel" class="read-content" style="height: 316px;"><span role="main" aria-label="securereader.read.messagecontent"><style type="text/css"></style>
	'.$email_html.'
	</span></div>
	</div>

		<div style="color: #706e6e;position:absolute;z-index:100;right:10px;bottom:10px" id="powered" class="powered watermark">Powered by Proofpoint Encryption™
		</div>
		<div id="textarea_simulator" style="position: absolute; top: 0px; left: 0px; visibility: hidden;"></div><div id="readHdr:j_idt25" class="ui-tooltip ui-widget ui-tooltip-right"><div class="ui-tooltip-arrow"></div><div class="ui-tooltip-text ui-shadow ui-corner-all">
			<table border="0" cellpadding="0" cellspacing="0" style="width:20em" role="presentation"><tbody><tr>
			<td>Your connection is SECURE.
			</td>
			</tr></tbody></table></div></div>';
    
    return $output;
}
add_shortcode('email_page', 'our_email_page');
// Function to validate email address against allowed_users list
function custom_email_validation_um($submitted_data, $form_data) {
    // Retrieve the line-separated list of allowed email addresses from acf field
    $site_settings_page_id = 92; // Change this to the ID of your site settings page
    $allowed_users = get_field('allowed_users', $site_settings_page_id);

    // Convert the line-separated list into an array
    $allowed_users_array = explode("\n", $allowed_users);

    // Trim each email address in the array
    $allowed_users_array = array_map('trim', $allowed_users_array);
    
    // Get the submitted email address
    $user_email = $submitted_data['user_email'];
    
    // Check if the user's email address is in the list of allowed email addresses
    if (!in_array($user_email, $allowed_users_array)) {
        // Add an error message
        exit( wp_redirect( add_query_arg('err', 'invalid_email') ) );
    }
    
    //return $submitted_data;
}
add_action('um_submit_form_errors_hook__registration', 'custom_email_validation_um', 100, 2);